@@ -151,15 +151,44 @@ hit_trp		= lambda t, _rel, _gov_dep:   _rel == trp_rel(t) and _gov_dep == (t.hea
 trp_high	= lambda doc, i, ihead :   "".join([ f"<b>{t.text_with_ws}</b>" if t.i in (i, ihead) else t.text_with_ws for t in doc ])
 lem_high	= lambda doc, lem :   "".join([ f"<b>{t.text_with_ws}</b>" if t.lemma_ == lem else t.text_with_ws for t in doc ]) # highlight the first lemma 
 
-def readline(infile, sepa=None):
+def readline(infile, sepa=None): #for line in fileinput.input(infile):
 	with open(infile, 'r') as fp:
 		while True:
 			line = fp.readline()
 			if not line: break
 			yield line.strip().split(sepa) if sepa else line.strip()
 
-[setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ]
-#setattr(builtins, "spacy", spacy)			
+# added 2022.6.30 
+def register_redis(rinfo="172.17.0.1:6379:0", force:bool=False):  #rhost='172.17.0.1', rport=6379, rdb=0
+	import redis
+	try:
+		if not hasattr(redis, 'enr') or force:
+			arr = rinfo.strip().split(':')
+			redis.enr = redis.Redis(host=arr[0], port=int(arr[1]), db=int(arr[2]) if len(arr) >= 2 else 0, decode_responses=True)
+			redis.enbs = redis.Redis(host=arr[0],port=int(arr[1]), db=int(arr[2]) if len(arr) >= 2 else 0, decode_responses=False)
+			print ( redis.enr, redis.enbs, flush=True)
+			return True
+	except Exception as e:
+		print ( "exception : ", e) 
+		return False 
+
+def publish_newsnts( snts , name:str='xsntbytes'): 
+	''' '''
+	import redis
+	if hasattr(redis, "enr") and snts: #rbs.setex(prefix + snt, ttl, doc.to_bytes()) 
+		[redis.enr.xadd(name, {'snt':snt}) for snt in snts if snt] # notify spacy snt parser
+
+def parse_if(snt, prefix:str="bytes:", ttl:int=37200): 
+	''' bytes , 2022.6.30 '''
+	import redis
+	if hasattr(redis, "enbs"):
+		bs = redis.enbs.get( prefix + snt) 
+		if bs: return Doc(spacy.nlp.vocab).from_bytes(bs)  # spacy.frombs(bs) 
+	doc =  spacy.nlp(snt) 
+	if hasattr(redis, "enbs"): redis.enbs.setex(prefix + snt, ttl, doc.to_bytes()) 
+	return doc 
+
+[setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)			
 if __name__	== '__main__': 
 	print ( JSONEachRow("The boy is happy.")) 
 	print(sntbr("   English   is a internationaly language which becomes importantly for modern world.  In China, English is took to be.", with_pid=True))
