@@ -126,10 +126,9 @@ def ske(doc):
 
 def clause(doc):  # {'S.prep-0': {'type': 'S.prep', 'start': 0, 'end': 2, 'lem': 'consider', 'chunk': 'Considering the possibility'}, 'S.conj-9': {'type': 'S.conj', 'start': 9, 'end': 12, 'lem': 'be', 'chunk': 'she is ok .'}}
 	for v in [t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT' ] : # non-root
-		children = list(v.subtree)
-		start = children[0].i  	#end = children[-1].i 
-		type = "S." + v.dep_   # S.advcl ,  S.conj 
-		doc.user_data[f"{type}-{start}"] = {"type":type, "start": start, "end":children[-1].i + 1, "lem":v.lemma_,"lempos":v.lemma_ + "_" + v.pos_,"chunk": " ".join([c.text for c in v.subtree])}
+		children = list(v.subtree) #end = children[-1].i 	tag = "S." + v.dep_   # S.advcl ,  S.conj 
+		start = children[0].i
+		doc.user_data[f"{type}-{start}"] = {"type":"cl", "tag": "S." + v.dep_,  "start": start, "end":children[-1].i + 1, "lem":v.lemma_,"lempos":v.lemma_ + "_" + v.pos_,"chunk": " ".join([c.text for c in v.subtree])}
 
 def attach(doc):
 	verbnet(doc)
