@@ -1,6 +1,6 @@
 #from uvirun import * 
 #uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload
-import json,os,uvicorn,time, fastapi
+import json,os,uvicorn,time, fastapi,platform,requests
 from fastapi import FastAPI, File, UploadFile,Form, Body
 from fastapi.responses import HTMLResponse
 
