@@ -1,9 +1,8 @@
 # 2022.6.30 cp from uvicorn corpusly-19200:app --host 0.0.0.0 --port 19200 --reload
-import json,os,re, requests,traceback,fire, time,math,collections , hashlib,uvicorn,os,fastapi, platform
-from fastapi import FastAPI, File, UploadFile,Form, Body
+from uvirun import *
 from util import likelihood
 import pandas as pd
-if not 'app' in dir(): 	app	 = fastapi.FastAPI()
+import platform
 
 from so import *
 requests.eshost	= os.getenv("eshost", "es.corpusly.com" if "Windows" in platform.system() else "172.17.0.1")
@@ -139,4 +138,4 @@ def init_index(idxname:str='testidx'):  requests.es.newindex(idxname)
 
 if __name__ == "__main__":  
 	print (es_query_termcnt())
-	#uvicorn.run(app, host='0.0.0.0', port=19200)
\ No newline at end of file
+	uvicorn.run(app, host='0.0.0.0', port=80)
\ No newline at end of file
