@@ -1,6 +1,6 @@
 # 2022.6.29  
-import json,os,uvicorn,spacy, fastapi
-if not 'app' in dir(): 	app	 = fastapi.FastAPI()
+from uvirun import *
+import spacy
 if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_sm')
 
 @app.get('/spacy/toks')
